

# ShiWei   is First  Demo 



```tex
F:.
│  LICENSE
│  README.md
│  setup.py
│  tree.txt
│  
├─build
│  ├─bdist.win-amd64
│  └─lib
│      └─shiwei_demo
│              suosuo.py
│              __init__.py
│              
├─dist
│      shiwei_demo-0.0.1-py3-none-any.whl
│      shiwei_demo-0.0.1.tar.gz
│      
├─shiwei_demo
│      suosuo.py
│      __init__.py
│      
└─shiwei_demo.egg-info
        dependency_links.txt
        PKG-INFO
        SOURCES.txt
        top_level.txt    


```

